# [1.3.12](https://github.com/seriaati/yatta/compare/v1.3.11..v1.3.12) - 2025-01-16

## Bug Fixes

- Fix unexpected SkillListSkill type - ([bbd61f3](https://github.com/seriaati/yatta/commit/bbd61f3d76b07db4b4865ef17ae361e481badce2))

## Features

- Add version fetching - ([5c0ef18](https://github.com/seriaati/yatta/commit/5c0ef18c74ef24a4b81abf5888dfe5266ebdf8cf))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#69](https://github.com/seriaati/yatta/issues/69)) - ([d7833dd](https://github.com/seriaati/yatta/commit/d7833dd199f6cbff165cc7aa6c7cfbea0c2c05e4))
- **(deps)** lock file maintenance ([#70](https://github.com/seriaati/yatta/issues/70)) - ([5e94bbd](https://github.com/seriaati/yatta/commit/5e94bbdf6f97625c9c89438a21484fa175a3b7c1))
- **(deps)** lock file maintenance ([#71](https://github.com/seriaati/yatta/issues/71)) - ([d79584a](https://github.com/seriaati/yatta/commit/d79584ad21eb47aaaf3f231a3c684ff8a084ec7a))
- **(deps)** lock file maintenance ([#72](https://github.com/seriaati/yatta/issues/72)) - ([0ddf22d](https://github.com/seriaati/yatta/commit/0ddf22deef862d38a2800dd52f4eee38393a3f6c))
- **(deps)** lock file maintenance ([#73](https://github.com/seriaati/yatta/issues/73)) - ([075d540](https://github.com/seriaati/yatta/commit/075d540c2f8f878ad27422ec15287d6ab7177de7))
- **(ruff)** Ignore test.py - ([615d232](https://github.com/seriaati/yatta/commit/615d2324b35395f223381161937c414da7dfa0d9))

